@@ -1,4 +1,4 @@
-# Copyright (c) 2007-2010 by Lorenzo Gil Sanchez <lorenzo.gil.sanchez@gmail.com>
+# Copyright (c) 2007-2019 by Lorenzo Gil Sanchez <lorenzo.gil.sanchez@gmail.com>
 #
 # This file is part of PyCha.
 #
@@ -17,12 +17,13 @@
 
 import unittest
 
-import bar
-import chart
-import color
-import line
-import pie
-import utils
+from . import bar
+from . import chart
+from . import color
+from . import line
+from . import pie
+from . import utils
+
 
 def test_suite():
     return unittest.TestSuite((
@@ -34,5 +35,6 @@ def test_suite():
         utils.test_suite(),
     ))
 
+
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
